:mod:`npdl.utils`
=================


.. automodule:: npdl.utils

.. toctree::
   :maxdepth: 2

   utils/data
   utils/random


.. npdl/utils/data.py

.. rubric:: :doc:`utils/data`

.. autosummary::
   :nosignatures:

   one_hot
   unhot


.. npdl/utils/random.py

.. rubric:: :doc:`utils/random`

.. autosummary::
   :nosignatures:

   get_rng
   set_rng
   set_seed
   get_dtype
   set_dtype
